# Add dependencies for your component
include(CMakeFindDependencyMacro)

# This might seem like overkill, but it's best not to define
# Boost_USE_STATIC_LIBS if the user hasn't made a non-default choice (default
# is OFF). Additionally, we need to check that linking styles aren't mixed.
set(_COMPILED_WITH_STATIC_BOOST )
if(_COMPILED_WITH_STATIC_BOOST)
  if(DEFINED Boost_USE_STATIC_LIBS AND NOT Boost_USE_STATIC_LIBS)
    message(FATAL_ERROR "Scine Core was compiled with static boost, but you have set the use of the shared boost libraries! Cannot mix static and shared linking.")
  endif()
  set(Boost_USE_STATIC_LIBS ON)
endif()
unset(_COMPILED_WITH_STATIC_BOOST)

if(NOT TARGET Boost::filesystem OR NOT TARGET Boost::system)
  unset(Boost_FOUND)
  find_dependency(Boost REQUIRED COMPONENTS filesystem system)
endif()

if(DEFINED SCINE_MARCH AND NOT "${SCINE_MARCH}" STREQUAL "")
  message(FATAL_ERROR "You are trying to use an installed version of SCINE Core that was compiled with different -march flag values! Current march flags: ${SCINE_MARCH}, installed flags: ")
endif()
if (NOT DEFINED SCINE_MARCH)
  set(SCINE_MARCH "")
endif()

include(${CMAKE_CURRENT_LIST_DIR}/ScineCoreTargets.cmake)


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

check_required_components(Core)
